###########################################################################
#
# win32 makefile -- src/colservr
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the
# University of Waikato, New Zealand.
#
# Copyright (C) 1999  The New Zealand Digital Library Project
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

GSDLHOME = ..\..
GSDL_VC4 = 0
DLL = 0
DLLDEBUG = 0
USE_Z3950=0
STLPATH = "$(GSDLHOME)\packages\windows\stlport\stlport"

AR = lib
CC = cl

!IF $(GSDL_VC4)
CPPFLAGS = -GX
!ELSE
CPPFLAGS = -EHsc
!ENDIF

!IF $(DLL)
CPPFLAGS = $(CPPFLAGS) -MD
!ELSE
!IF ($(DLLDEBUG))
CPPFLAGS = $(CPPFLAGS) -MDd
!ENDIF
!ENDIF

LDFLAGS =
DEFS = -D__WIN32__ -DHAVE_CONFIG_H -DPARADOCNUM -D_LITTLE_ENDIAN -DSHORT_SUFFIX -DXML_STATIC -D_CRT_SECURE_NO_DEPRECATE
INCLUDES = -I"$(GSDLHOME)" -I"$(GSDLHOME)\lib" -I"$(GSDLHOME)\src\colservr" \
	   -I"$(GSDLHOME)\src\recpt" -I"$(GSDLHOME)\packages\mg" \
	   -I"$(GSDLHOME)\packages\mg\lib" -I"$(GSDLHOME)\packages\mg\src\text" \
	   -I"$(GSDLHOME)\packages\windows\gdbm\gdbm" \
           -I"$(GSDLHOME)\src\mgpp\lib" -I"$(GSDLHOME)\src\mgpp\text" \
           -I"$(GSDLHOME)\packages\windows\expat\expat"

!IF $(GSDL_VC4)
DEFS=$(DEFS) -DGSDL_NAMESPACE_BROKEN -DGSDL_USE_IOS_H -D__STL_NO_NEW_IOSTREAMS
INCLUDES = $(INCLUDES) -I$(STLPATH)
!ENDIF

LIBS =

COMPILE = $(CC) -nologo -c $(CPPFLAGS) $(DEFS) $(INCLUDES)
LINK = $(CC) -nologo $(LDFLAGS)

.SUFFIXES:
.SUFFIXES: .c .obj
.c.obj:
	$(COMPILE) $<

.SUFFIXES: .cpp .obj
.cpp.obj:
	$(COMPILE) $< 

!IF $(USE_Z3950)
INCLUDES = $(INCLUDES) -I"$(GSDLHOME)\packages\yaz\yaz-2.1.4\include" -I"$(GSDLHOME)\packages\d2m"
Z3950HEADERS = 
Z3950SOURCES = z3950parser.cpp z3950explain.cpp z3950_to_gsdl.cpp \
	       z3950server.cpp read-grs.cpp
Z3950OBJECTS = z3950parser.obj   z3950explain.obj   z3950_to_gsdl.obj   \
	       z3950server.obj   read-grs.obj
Z3950LIB = gsdlz3950.lib
!ELSE
Z3950HEADERS = 
Z3950SOURCES = 
Z3950OBJECTS = 
Z3950LIB =
!ENDIF

HEADERS = mgq.h search.h mgsearch.h querycache.h queryinfo.h collectserver.h \
          colservrconfig.h maptools.h filter.h source.h browsefilter.h \
          queryfilter.h mgqueryfilter.h mggdbmsource.h phrasesearch.h \
          phrasequeryfilter.h collectset.h mgppsearch.h mgppqueryfilter.h \
          lucenegdbmsource.h lucenequeryfilter.h lucenesearch.h \
          expat_resultset.h expat_document.h gdbmsource.h

SOURCES = mgq.c search.cpp mgsearch.cpp querycache.cpp queryinfo.cpp \
	  collectserver.cpp colservrconfig.cpp maptools.cpp filter.cpp \
	  source.cpp browsefilter.cpp queryfilter.cpp mgqueryfilter.cpp \
	  mggdbmsource.cpp phrasesearch.cpp phrasequeryfilter.cpp \
          collectset.cpp mgppsearch.cpp mgppqueryfilter.cpp \
          lucenegdbmsource.cpp lucenequeryfilter.cpp lucenesearch.cpp \
          expat_resultset.cpp expat_document.cpp gdbmsource.cpp

OBJECTS = mgq.obj search.obj mgsearch.obj querycache.obj queryinfo.obj \
	  collectserver.obj colservrconfig.obj maptools.obj filter.obj \
	  source.obj browsefilter.obj queryfilter.obj mgqueryfilter.obj \
	  mggdbmsource.obj phrasesearch.obj phrasequeryfilter.obj \
          collectset.obj mgppsearch.obj mgppqueryfilter.obj \
          lucenegdbmsource.obj lucenequeryfilter.obj lucenesearch.obj \
          expat_resultset.obj expat_document.obj gdbmsource.obj 
	

all : gsdlcolservr.lib $(Z3950LIB)

gsdlcolservr.lib : $(OBJECTS) 
	if EXIST gsdlcolservr.lib del gsdlcolservr.lib
	$(AR) -nologo /out:gsdlcolservr.lib $(OBJECTS)

gsdlz3950.lib : $(Z3950OBJECTS)
	if EXIST gsdlz3950.lib del gsdlz3950.lib
	$(AR) -nologo /out:gsdlz3950.lib $(Z3950OBJECTS)
clean:
	del *.obj
	del gsdlcolservr.lib
	del gsdlz3950.lib

install:
